==> frostiful-2.2.6%2B1.21.1-sources.jar: com/github/thedeathlycow/frostiful/item/IcicleItem.java <==
package com.github.thedeathlycow.frostiful.item;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.entity.ThrownIcicleEntity;
import com.github.thedeathlycow.frostiful.registry.FSoundEvents;
import net.minecraft.class_1268;
import net.minecraft.class_1271;
import net.minecraft.class_1657;
import net.minecraft.class_1665;
import net.minecraft.class_1676;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2350;
import net.minecraft.class_2374;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_9463;

public class IcicleItem extends class_1747 implements class_9463 {


    public IcicleItem(class_2248 block, class_1792.class_1793 settings) {
        super(block, settings);
    }

    @Override
    public class_1271<class_1799> method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 itemStack = user.method_5998(hand);

        world.method_43128(
                null,
                user.method_23317(), user.method_23318(), user.method_23321(),
                FSoundEvents.ENTITY_THROWN_ICICLE_THROW, class_3419.field_15254,
                0.5f, 0.4f / (world.method_8409().method_43057() * 0.4f + 0.8f)
        );

        if (!world.field_9236) {
            ThrownIcicleEntity icicleEntity = new ThrownIcicleEntity(world, user, itemStack.method_46651(1));

            icicleEntity.method_24919(
                    user,
                    user.method_36455(), user.method_36454(),
                    0.0f, 1.0f, 1.0f
            );
            if (user.method_31549().field_7477) {
                icicleEntity.field_7572 = class_1665.class_1666.field_7594;
            }

            world.method_8649(icicleEntity);
        }

        user.method_7259(class_3468.field_15372.method_14956(this));
        itemStack.method_57008(1, user);
        user.method_7357().method_7906(this, Frostiful.getConfig().icicleConfig.getThrownIcicleCooldown());

        return class_1271.method_29237(itemStack, world.method_8608());
    }

    @Override
    public class_1676 method_58648(class_1937 world, class_2374 pos, class_1799 stack, class_2350 direction) {
        ThrownIcicleEntity icicleEntity = new ThrownIcicleEntity(world, pos.method_10216(), pos.method_10214(), pos.method_10215(), stack.method_46651(1));
        icicleEntity.field_7572 = class_1665.class_1666.field_7593;
        return icicleEntity;
    }
}

==> frostiful-2.2.8%2B1.21.8-sources.jar: com/github/thedeathlycow/frostiful/item/IcicleItem.java <==
package com.github.thedeathlycow.frostiful.item;

import com.github.thedeathlycow.frostiful.Frostiful;
import com.github.thedeathlycow.frostiful.entity.ThrownIcicleEntity;
import com.github.thedeathlycow.frostiful.registry.FSoundEvents;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1665;
import net.minecraft.class_1676;
import net.minecraft.class_1747;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2350;
import net.minecraft.class_2374;
import net.minecraft.class_3419;
import net.minecraft.class_3468;
import net.minecraft.class_9463;

public class IcicleItem extends class_1747 implements class_9463 {
    public IcicleItem(class_2248 block, class_1792.class_1793 settings) {
        super(block, settings.method_63685());
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        class_1799 itemStack = user.method_5998(hand);

        world.method_43128(
                null,
                user.method_23317(), user.method_23318(), user.method_23321(),
                FSoundEvents.ENTITY_THROWN_ICICLE_THROW, class_3419.field_15254,
                0.5f, 0.4f / (world.method_8409().method_43057() * 0.4f + 0.8f)
        );

        if (!world.field_9236) {
            ThrownIcicleEntity icicleEntity = new ThrownIcicleEntity(world, user, itemStack.method_46651(1));

            icicleEntity.method_24919(
                    user,
                    user.method_36455(), user.method_36454(),
                    0.0f, 1.0f, 1.0f
            );
            if (user.method_31549().field_7477) {
                icicleEntity.field_7572 = class_1665.class_1666.field_7594;
            }

            world.method_8649(icicleEntity);
        }

        user.method_7259(class_3468.field_15372.method_14956(this));
        itemStack.method_57008(1, user);
        user.method_7357().method_62835(itemStack, Frostiful.getConfig().icicleConfig.getThrownIcicleCooldown());

        return class_1269.field_5812;
    }

    @Override
    public class_1676 method_58648(class_1937 world, class_2374 pos, class_1799 stack, class_2350 direction) {
        ThrownIcicleEntity icicleEntity = new ThrownIcicleEntity(world, pos.method_10216(), pos.method_10214(), pos.method_10215(), stack.method_46651(1));
        icicleEntity.field_7572 = class_1665.class_1666.field_7593;
        return icicleEntity;
    }
}
